Subject: Re: SiS 900 Ethernet (was: SiS 630E audio support?)
To: None <thorpej@wasabisystems.com>
From: Gary Duzan <gary@duzan.org>
List: port-i386
Date: 12/20/2001 20:07:25
------- =_aaaaaaaaaa0
Content-Type: text/plain; charset="us-ascii"
Content-ID: <338.1008896829.1@capo.xnet.duzan.org>

In Message <20011220104144.E9607@dr-evil.shagadelic.org> ,
   Jason R Thorpe <thorpej@wasabisystems.com> wrote:

=>On Thu, Dec 20, 2001 at 10:51:57AM +0000, Stephen Borrill wrote:
=>
=> > Yes, that correctly deduces the MAC address. Shall I submit the NFS
=> > and auto media detect problems as separate PRs?
=>
=>Yes, plesae.  A separate one for each.

   BTW, the SiS 735 chipset had similar problems. The attached
patch allows the driver to correctly deduce the MAC address, and
I can ping a remote host. NFS is broken though, as mentioned above,
so it is still not usable for me. I also see messages like these:

At Boot Time
============
sip0: master abort

NFS Attempts
============
sip0: discarding oversize frame (len=2047)

When Rebooting
==============
sip0: device timeout

					Gary D. Duzan



------- =_aaaaaaaaaa0
Content-Type: text/plain; charset="us-ascii"
Content-ID: <338.1008896829.2@capo.xnet.duzan.org>
Content-Description: sis735.patch

Index: if_sipreg.h
===================================================================
RCS file: /cvsroot/syssrc/sys/dev/pci/if_sipreg.h,v
retrieving revision 1.8
diff -u -r1.8 if_sipreg.h
--- if_sipreg.h	2001/12/20 03:32:31	1.8
+++ if_sipreg.h	2001/12/21 00:57:18
@@ -696,6 +696,11 @@
 #define	SIS_REV_630EA1	0x83
 
 /*
+ * Revision codes for the SiS 735 chipset built-in Ethernet.
+ */
+#define	SIS_REV_735	0x90
+
+/*
  * Serial EEPROM opcodes, including the start bit.
  */
 #define	SIP_EEPROM_OPC_ERASE	0x04

------- =_aaaaaaaaaa0--
Index: if_sip.c
===================================================================
RCS file: /cvsroot/syssrc/sys/dev/pci/if_sip.c,v
retrieving revision 1.44
diff -u -r1.44 if_sip.c
--- if_sip.c	2001/12/20 03:32:31	1.44
+++ if_sip.c	2001/12/21 00:57:14
@@ -2992,9 +2992,10 @@
 	case SIS_REV_630S:
 	case SIS_REV_630E:
 	case SIS_REV_630EA1:
+	case SIS_REV_735:
 		/*
 		 * The MAC address for the on-board Ethernet of
 		 * the SiS 630 chipset is in the NVRAM.  Kick
 		 * the chip into re-loading it from NVRAM, and
 		 * read the MAC address out of the filter registers.
 		 */
@@ -2992,9 +2992,10 @@
 		/*
 		 * The MAC address for the on-board Ethernet of
-		 * the SiS 630 chipset is in the NVRAM.  Kick
+		 * the SiS 630/735 chipset is in the NVRAM.  Kick
 		 * the chip into re-loading it from NVRAM, and
 		 * read the MAC address out of the filter registers.